% Auto-generated chapter 46 for bukhari
% Hadiths in this chapter: 43

\hadithdefcmd{bukhari}{2440}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا مُعَاذُ بْنُ هِشَامٍ، حَدَّثَنِي أَبِي، عَنْ قَتَادَةَ، عَنْ أَبِي الْمُتَوَكِّلِ النَّاجِيِّ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ ـ رضى الله عنه ـ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا خَلَصَ الْمُؤْمِنُونَ مِنَ النَّارِ حُبِسُوا بِقَنْطَرَةٍ بَيْنَ الْجَنَّةِ وَالنَّارِ، فَيَتَقَاصُّونَ مَظَالِمَ كَانَتْ بَيْنَهُمْ فِي الدُّنْيَا، حَتَّى إِذَا نُقُّوا وَهُذِّبُوا أُذِنَ لَهُمْ بِدُخُولِ الْجَنَّةِ، فَوَالَّذِي نَفْسُ مُحَمَّدٍ صلى الله عليه وسلم بِيَدِهِ لأَحَدُهُمْ بِمَسْكَنِهِ فِي الْجَنَّةِ أَدَلُّ بِمَنْزِلِهِ كَانَ فِي الدُّنْيَا ‏"‏‏.‏ وَقَالَ يُونُسُ بْنُ مُحَمَّدٍ حَدَّثَنَا شَيْبَانُ عَنْ قَتَادَةَ حَدَّثَنَا أَبُو الْمُتَوَكِّلِ‏.‏\hadithno{2440}\hadithtrans{Narrated Abu Sa`id Al-Khudri:Allah's Messenger (ﷺ) said, "When the believers pass safely over (the bridge across) Hell, they will be stopped at a bridge in between Hell and Paradise where they will retaliate upon each other for the injustices done among them in the world, and when they get purified of all their sins, they will be admitted into Paradise. By Him in Whose Hands the life of Muhammad is everybody will recognize his dwelling in Paradise better than he recognizes his dwelling in this world}}
\hadithdefcmd{bukhari}{2441}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا هَمَّامٌ، قَالَ أَخْبَرَنِي قَتَادَةُ، عَنْ صَفْوَانَ بْنِ مُحْرِزٍ الْمَازِنِيِّ، قَالَ بَيْنَمَا أَنَا أَمْشِي، مَعَ ابْنِ عُمَرَ ـ رضى الله عنهما ـ آخِذٌ بِيَدِهِ إِذْ عَرَضَ رَجُلٌ، فَقَالَ كَيْفَ سَمِعْتَ رَسُولَ اللَّهِ صلى الله عليه وسلم فِي النَّجْوَى فَقَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّ اللَّهَ يُدْنِي الْمُؤْمِنَ فَيَضَعُ عَلَيْهِ كَنَفَهُ، وَيَسْتُرُهُ فَيَقُولُ أَتَعْرِفُ ذَنْبَ كَذَا أَتَعْرِفُ ذَنْبَ كَذَا فَيَقُولُ نَعَمْ أَىْ رَبِّ‏.‏ حَتَّى إِذَا قَرَّرَهُ بِذُنُوبِهِ وَرَأَى فِي نَفْسِهِ أَنَّهُ هَلَكَ قَالَ سَتَرْتُهَا عَلَيْكَ فِي الدُّنْيَا، وَأَنَا أَغْفِرُهَا لَكَ الْيَوْمَ‏.‏ فَيُعْطَى كِتَابَ حَسَنَاتِهِ، وَأَمَّا الْكَافِرُ وَالْمُنَافِقُونَ فَيَقُولُ الأَشْهَادُ هَؤُلاَءِ الَّذِينَ كَذَبُوا عَلَى رَبِّهِمْ، أَلاَ لَعْنَةُ اللَّهِ عَلَى الظَّالِمِينَ ‏"‏‏.‏\hadithno{2441}\hadithtrans{Narrated Safwan bin Muhriz Al-Mazini:While I was walking with Ibn `Umar holding his hand, a man came in front of us and asked, "What have you heard from Allah's Messenger (ﷺ) about An-Najwa?" Ibn `Umar said, "I heard Allah's Messenger (ﷺ) saying, 'Allah will bring a believer near Him and shelter him with His Screen and ask him: Did you commit such-and-such sins? He will say: Yes, my Lord. Allah will keep on asking him till he will confess all his sins and will think that he is ruined. Allah will say: 'I did screen your sins in the world and I forgive them for you today', and then he will be given the book of his good deeds. Regarding infidels and hypocrites (their evil acts will be exposed publicly) and the witnesses will say: These are the people who lied against their Lord. Behold! The Curse of Allah is upon the wrongdoers}}
\hadithdefcmd{bukhari}{2442}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، أَنَّ سَالِمًا، أَخْبَرَهُ أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ ـ رضى الله عنهما ـ أَخْبَرَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الْمُسْلِمُ أَخُو الْمُسْلِمِ، لاَ يَظْلِمُهُ وَلاَ يُسْلِمُهُ، وَمَنْ كَانَ فِي حَاجَةِ أَخِيهِ كَانَ اللَّهُ فِي حَاجَتِهِ، وَمَنْ فَرَّجَ عَنْ مُسْلِمٍ كُرْبَةً فَرَّجَ اللَّهُ عَنْهُ كُرْبَةً مِنْ كُرُبَاتِ يَوْمِ الْقِيَامَةِ، وَمَنْ سَتَرَ مُسْلِمًا سَتَرَهُ اللَّهُ يَوْمَ الْقِيَامَةِ ‏"‏‏.‏\hadithno{2442}\hadithtrans{Narrated `Abdullah bin `Umar:Allah's Messenger (ﷺ) said, "A Muslim is a brother of another Muslim, so he should not oppress him, nor should he hand him over to an oppressor. Whoever fulfilled the needs of his brother, Allah will fulfill his needs; whoever brought his (Muslim) brother out of a discomfort, Allah will bring him out of the discomforts of the Day of Resurrection, and whoever screened a Muslim, Allah will screen him on the Day of Resurrection}}
\hadithdefcmd{bukhari}{2443}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا هُشَيْمٌ، أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ أَبِي بَكْرِ بْنِ أَنَسٍ، وَحُمَيْدٌ الطَّوِيلُ، سَمِعَا أَنَسَ بْنَ مَالِكٍ ـ رضى الله عنه ـ يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ انْصُرْ أَخَاكَ ظَالِمًا أَوْ مَظْلُومًا ‏"‏‏.‏\hadithno{2443}\hadithtrans{Narrated Anas bin Malik:Allah's Messenger (ﷺ) said, "Help your brother, whether he is an oppressor or he is an oppressed one}}
\hadithdefcmd{bukhari}{2444}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا مُعْتَمِرٌ، عَنْ حُمَيْدٍ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ انْصُرْ أَخَاكَ ظَالِمًا أَوْ مَظْلُومًا ‏"‏‏.‏ قَالُوا يَا رَسُولَ اللَّهِ هَذَا نَنْصُرُهُ مَظْلُومًا، فَكَيْفَ نَنْصُرُهُ ظَالِمًا قَالَ ‏"‏ تَأْخُذُ فَوْقَ يَدَيْهِ ‏"‏‏.‏\hadithno{2444}\hadithtrans{Narrated Anas:Allah's Messenger (ﷺ) said, "Help your brother, whether he is an oppressor or he is an oppressed one. People asked, "O Allah's Messenger (ﷺ)! It is all right to help him if he is oppressed, but how should we help him if he is an oppressor?" The Prophet (ﷺ) said, "By preventing him from oppressing others}}
\hadithdefcmd{bukhari}{2445}{حَدَّثَنَا سَعِيدُ بْنُ الرَّبِيعِ، حَدَّثَنَا شُعْبَةُ، عَنِ الأَشْعَثِ بْنِ سُلَيْمٍ، قَالَ سَمِعْتُ مُعَاوِيَةَ بْنَ سُوَيْدٍ، سَمِعْتُ الْبَرَاءَ بْنَ عَازِبٍ ـ رضى الله عنهما ـ قَالَ أَمَرَنَا النَّبِيُّ صلى الله عليه وسلم بِسَبْعٍ، وَنَهَانَا عَنْ سَبْعٍ‏.‏ فَذَكَرَ عِيَادَةَ الْمَرِيضِ، وَاتِّبَاعَ الْجَنَائِزِ، وَتَشْمِيتَ الْعَاطِسِ، وَرَدَّ السَّلاَمِ، وَنَصْرَ الْمَظْلُومِ، وَإِجَابَةَ الدَّاعِي، وَإِبْرَارَ الْمُقْسِمِ‏.‏\hadithno{2445}\hadithtrans{Narrated Muawiya bin Suwaid:I heard Al-Bara' bin `Azib saying, "The Prophet (ﷺ) ordered us to do seven things and prohibited us from doing seven other things." Then Al-Bara' mentioned the following:-- (1) To pay a visit to the sick (inquiring about his health), (2) to follow funeral processions, (3) to say to a sneezer, "May Allah be merciful to you" (if he says, "Praise be to Allah!"), (4) to return greetings, (5) to help the oppressed, (6) to accept invitations, (7) to help others to fulfill their oaths. (See Hadith No. 753, Vol)}}
\hadithdefcmd{bukhari}{2446}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ بُرَيْدٍ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْمُؤْمِنُ لِلْمُؤْمِنِ كَالْبُنْيَانِ يَشُدُّ بَعْضُهُ بَعْضًا ‏"‏‏.‏ وَشَبَّكَ بَيْنَ أَصَابِعِهِ‏.‏\hadithno{2446}\hadithtrans{Narrated Abu Musa:The Prophet (ﷺ) said, "A believer to another believer is like a building whose different parts enforce each other." The Prophet (ﷺ) then clasped his hands with the fingers interlaced (while saying that)}}
\hadithdefcmd{bukhari}{2447}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا عَبْدُ الْعَزِيزِ الْمَاجِشُونُ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ دِينَارٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الظُّلْمُ ظُلُمَاتٌ يَوْمَ الْقِيَامَةِ ‏"‏‏.‏\hadithno{2447}\hadithtrans{Narrated Ibn `Umar:The Prophet (ﷺ) said, "Oppression will be a darkness on the Day of Resurrection}}
\hadithdefcmd{bukhari}{2448}{حَدَّثَنَا يَحْيَى بْنُ مُوسَى، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا زَكَرِيَّاءُ بْنُ إِسْحَاقَ الْمَكِّيُّ، عَنْ يَحْيَى بْنِ عَبْدِ اللَّهِ بْنِ صَيْفِيٍّ، عَنْ أَبِي مَعْبَدٍ، مَوْلَى ابْنِ عَبَّاسٍ عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم بَعَثَ مُعَاذًا إِلَى الْيَمَنِ، فَقَالَ ‏ "‏ اتَّقِ دَعْوَةَ الْمَظْلُومِ، فَإِنَّهَا لَيْسَ بَيْنَهَا وَبَيْنَ اللَّهِ حِجَابٌ ‏"‏‏.‏\hadithno{2448}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) sent Mu`adh to Yemen and said, "Be afraid, from the curse of the oppressed as there is no screen between his invocation and Allah}}
\hadithdefcmd{bukhari}{2449}{حَدَّثَنَا آدَمُ بْنُ أَبِي إِيَاسٍ، حَدَّثَنَا ابْنُ أَبِي ذِئْبٍ، حَدَّثَنَا سَعِيدٌ الْمَقْبُرِيُّ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ كَانَتْ لَهُ مَظْلَمَةٌ لأَحَدٍ مِنْ عِرْضِهِ أَوْ شَىْءٍ فَلْيَتَحَلَّلْهُ مِنْهُ الْيَوْمَ، قَبْلَ أَنْ لاَ يَكُونَ دِينَارٌ وَلاَ دِرْهَمٌ، إِنْ كَانَ لَهُ عَمَلٌ صَالِحٌ أُخِذَ مِنْهُ بِقَدْرِ مَظْلَمَتِهِ، وَإِنْ لَمْ تَكُنْ لَهُ حَسَنَاتٌ أُخِذَ مِنْ سَيِّئَاتِ صَاحِبِهِ فَحُمِلَ عَلَيْهِ ‏"‏‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ قَالَ إِسْمَاعِيلُ بْنُ أَبِي أُوَيْسٍ إِنَّمَا سُمِّيَ الْمَقْبُرِيَّ لأَنَّهُ كَانَ نَزَلَ نَاحِيَةَ الْمَقَابِرِ‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ وَسَعِيدٌ الْمَقْبُرِيُّ هُوَ مَوْلَى بَنِي لَيْثٍ، وَهُوَ سَعِيدُ بْنُ أَبِي سَعِيدٍ، وَاسْمُ أَبِي سَعِيدٍ كَيْسَانُ‏.‏\hadithno{2449}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "Whoever has oppressed another person concerning his reputation or anything else, he should beg him to forgive him before the Day of Resurrection when there will be no money (to compensate for wrong deeds), but if he has good deeds, those good deeds will be taken from him according to his oppression which he has done, and if he has no good deeds, the sins of the oppressed person will be loaded on him}}
\hadithdefcmd{bukhari}{2450}{حَدَّثَنَا مُحَمَّدٌ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها – ‏\{‏وَإِنِ امْرَأَةٌ خَافَتْ مِنْ بَعْلِهَا نُشُوزًا أَوْ إِعْرَاضًا‏\}‏ قَالَتِ الرَّجُلُ تَكُونُ عِنْدَهُ الْمَرْأَةُ، لَيْسَ بِمُسْتَكْثِرٍ مِنْهَا، يُرِيدُ أَنْ يُفَارِقَهَا، فَتَقُولُ أَجْعَلُكَ مِنْ شَأْنِي فِي حِلٍّ‏.‏ فَنَزَلَتْ هَذِهِ الآيَةُ فِي ذَلِكَ‏.‏\hadithno{2450}\hadithtrans{Narrated Aisha:Regarding the explanation of the following verse:-- "If a wife fears Cruelty or desertion On her husband's part." (4.128) A man may dislike his wife and intends to divorce her, so she says to him, "I give up my rights, so do not divorce me." The above verse was revealed concerning such a case}}
\hadithdefcmd{bukhari}{2451}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ أَبِي حَازِمِ بْنِ دِينَارٍ، عَنْ سَهْلِ بْنِ سَعْدٍ السَّاعِدِيِّ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أُتِيَ بِشَرَابٍ، فَشَرِبَ مِنْهُ وَعَنْ يَمِينِهِ غُلاَمٌ وَعَنْ يَسَارِهِ الأَشْيَاخُ، فَقَالَ لِلْغُلاَمِ ‏ "‏ أَتَأْذَنُ لِي أَنْ أُعْطِيَ هَؤُلاَءِ ‏"‏‏.‏ فَقَالَ الْغُلاَمُ لاَ وَاللَّهِ يَا رَسُولَ اللَّهِ لاَ أُوثِرُ بِنَصِيبِي مِنْكَ أَحَدًا‏.‏ قَالَ فَتَلَّهُ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي يَدِهِ‏.‏\hadithno{2451}\hadithtrans{Narrated Sahl bin Sa`d As-Sa`idi:A drink (milk mixed with water) was brought to Allah's Messenger (ﷺ) who drank some of it. A boy was sitting to his right, and some old men to his left. Allah's Messenger (ﷺ) said to the boy, "Do you allow me to give the rest of the drink to these people?" The boy said, "O Allah's Messenger (ﷺ)! I will not give preference to anyone over me to drink the rest of it from which you have drunk." Allah's Messenger (ﷺ) then handed the bowl (of drink) to the boy. (See Hadith No)}}
\hadithdefcmd{bukhari}{2452}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ حَدَّثَنِي طَلْحَةُ بْنُ عَبْدِ اللَّهِ، أَنَّ عَبْدَ الرَّحْمَنِ بْنَ عَمْرِو بْنِ سَهْلٍ، أَخْبَرَهُ أَنَّ سَعِيدَ بْنَ زَيْدٍ ـ رضى الله عنه ـ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ ظَلَمَ مِنَ الأَرْضِ شَيْئًا طُوِّقَهُ مِنْ سَبْعِ أَرَضِينَ ‏"‏‏.‏\hadithno{2452}\hadithtrans{Narrated Sa`id bin Zaid:Allah's Messenger (ﷺ) said, "Whoever usurps the land of somebody unjustly, his neck will be encircled with it down the seven earths (on the Day of Resurrection)}}
\hadithdefcmd{bukhari}{2453}{حَدَّثَنَا أَبُو مَعْمَرٍ، حَدَّثَنَا عَبْدُ الْوَارِثِ، حَدَّثَنَا حُسَيْنٌ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، قَالَ حَدَّثَنِي مُحَمَّدُ بْنُ إِبْرَاهِيمَ، أَنَّ أَبَا سَلَمَةَ، حَدَّثَهُ أَنَّهُ، كَانَتْ بَيْنَهُ وَبَيْنَ أُنَاسٍ خُصُومَةٌ، فَذَكَرَ لِعَائِشَةَ ـ رضى الله عنها ـ فَقَالَتْ يَا أَبَا سَلَمَةَ اجْتَنِبِ الأَرْضَ، فَإِنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ ظَلَمَ قِيدَ شِبْرٍ مِنَ الأَرْضِ طُوِّقَهُ مِنْ سَبْعِ أَرَضِينَ ‏"‏‏.‏\hadithno{2453}\hadithtrans{Narrated Abu Salama:That there was a dispute between him and some people (about a piece of land). When he told `Aisha about it, she said, "O Abu Salama! Avoid taking the land unjustly, for the Prophet (ﷺ) said, 'Whoever usurps even one span of the land of somebody, his neck will be encircled with it down the seven earths}}
\hadithdefcmd{bukhari}{2454}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، حَدَّثَنَا مُوسَى بْنُ عُقْبَةَ، عَنْ سَالِمٍ، عَنْ أَبِيهِ ـ رضى الله عنه ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ مَنْ أَخَذَ مِنَ الأَرْضِ شَيْئًا بِغَيْرِ حَقِّهِ خُسِفَ بِهِ يَوْمَ الْقِيَامَةِ إِلَى سَبْعِ أَرَضِينَ ‏"‏‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ هَذَا الْحَدِيثُ لَيْسَ بِخُرَاسَانَ فِي كِتَابِ ابْنِ الْمُبَارَكِ، أَمْلاَهُ عَلَيْهِمْ بِالْبَصْرَةِ‏.‏\hadithno{2454}\hadithtrans{Narrated Salim's father (i.e. `Abdullah):The Prophet (ﷺ) said, "Whoever takes a piece of the land of others unjustly, he will sink down the seven earths on the Day of Resurrection}}
\hadithdefcmd{bukhari}{2455}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا شُعْبَةُ، عَنْ جَبَلَةَ، كُنَّا بِالْمَدِينَةِ فِي بَعْضِ أَهْلِ الْعِرَاقِ، فَأَصَابَنَا سَنَةٌ، فَكَانَ ابْنُ الزُّبَيْرِ يَرْزُقُنَا التَّمْرَ، فَكَانَ ابْنُ عُمَرَ ـ رضى الله عنهما ـ يَمُرُّ بِنَا فَيَقُولُ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنِ الإِقْرَانِ، إِلاَّ أَنْ يَسْتَأْذِنَ الرَّجُلُ مِنْكُمْ أَخَاهُ‏.‏\hadithno{2455}\hadithtrans{Narrated Jabala:"We were in Medina with some of the Iraqi people, and we were struck with famine and Ibn Az-Zubair used to give us dates. Ibn `Umar used to pass by and say, "The Prophet (ﷺ) forbade us to eat two dates at a time, unless one takes the permission of one's companions}}
\hadithdefcmd{bukhari}{2456}{حَدَّثَنَا أَبُو النُّعْمَانِ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي وَائِلٍ، عَنْ أَبِي مَسْعُودٍ، أَنَّ رَجُلاً، مِنَ الأَنْصَارِ يُقَالُ لَهُ أَبُو شُعَيْبٍ كَانَ لَهُ غُلاَمٌ لَحَّامٌ فَقَالَ لَهُ أَبُو شُعَيْبٍ اصْنَعْ لِي طَعَامَ خَمْسَةٍ لَعَلِّي أَدْعُو النَّبِيَّ صلى الله عليه وسلم خَامِسَ خَمْسَةٍ‏.‏ وَأَبْصَرَ فِي وَجْهِ النَّبِيِّ صلى الله عليه وسلم الْجُوعَ ـ فَدَعَاهُ، فَتَبِعَهُمْ رَجُلٌ لَمْ يُدْعَ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِنَّ هَذَا قَدِ اتَّبَعَنَا أَتَأْذَنُ لَهُ ‏"‏‏.‏ قَالَ نَعَمْ‏.‏\hadithno{2456}\hadithtrans{Narrated Abu Mas`ud:There was an Ansari man called Abu Shu'aib who had a slave butcher. Abu Shu'aib said to him, "Prepare a meal sufficient for five persons so that I might invite the Prophet (ﷺ) besides other four persons." Abu Shu'aib had seen the signs of hunger on the face of the Prophet (ﷺ) and so he invited him. Another man who was not invited, followed the Prophet. The Prophet (ﷺ) said to Abu Shu'aib, "This man has followed us. Do you allow him to share the meal?" Abu Shu'aib said, "Yes}}
\hadithdefcmd{bukhari}{2457}{حَدَّثَنَا أَبُو عَاصِمٍ، عَنِ ابْنِ جُرَيْجٍ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ أَبْغَضَ الرِّجَالِ إِلَى اللَّهِ الأَلَدُّ الْخَصِمُ ‏"‏‏.‏\hadithno{2457}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) said, "The most hated person in the sight of Allah is the most quarrelsome person}}
\hadithdefcmd{bukhari}{2458}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنِي إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، أَنَّ زَيْنَبَ بِنْتَ أُمِّ سَلَمَةَ، أَخْبَرَتْهُ أَنَّ أُمَّهَا أُمَّ سَلَمَةَ ـ رضى الله عنها ـ زَوْجَ النَّبِيِّ صلى الله عليه وسلم أَخْبَرَتْهَا عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ سَمِعَ خُصُومَةً بِبَابِ حُجْرَتِهِ، فَخَرَجَ إِلَيْهِمْ، فَقَالَ ‏ "‏ إِنَّمَا أَنَا بَشَرٌ وَإِنَّهُ يَأْتِينِي الْخَصْمُ، فَلَعَلَّ بَعْضَكُمْ أَنْ يَكُونَ أَبْلَغَ مِنْ بَعْضٍ، فَأَحْسِبُ أَنَّهُ صَدَقَ، فَأَقْضِيَ لَهُ بِذَلِكَ، فَمَنْ قَضَيْتُ لَهُ بِحَقِّ مُسْلِمٍ فَإِنَّمَا هِيَ قِطْعَةٌ مِنَ النَّارِ، فَلْيَأْخُذْهَا أَوْ فَلْيَتْرُكْهَا ‏"‏‏.‏\hadithno{2458}\hadithtrans{Narrated Um Salama:(the wife of the Prophet) Allah's Messenger (ﷺ) heard some people quarreling at the door of his dwelling. He came out and said, "I am only a human being, and opponents come to me (to settle their problems); maybe someone amongst you can present his case more eloquently than the other, whereby I may consider him true and give a verdict in his favor. So, If I give the right of a Muslim to another by mistake, then it is really a portion of (Hell) Fire, he has the option to take or give up (before the Day of Resurrection)}}
\hadithdefcmd{bukhari}{2459}{حَدَّثَنَا بِشْرُ بْنُ خَالِدٍ، أَخْبَرَنَا مُحَمَّدٌ، عَنْ شُعْبَةَ، عَنْ سُلَيْمَانَ، عَنْ عَبْدِ اللَّهِ بْنِ مُرَّةَ، عَنْ مَسْرُوقٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو ـ رضى الله عنهما ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ أَرْبَعٌ مَنْ كُنَّ فِيهِ كَانَ مُنَافِقًا، أَوْ كَانَتْ فِيهِ خَصْلَةٌ مِنْ أَرْبَعَةٍ كَانَتْ فِيهِ خَصْلَةٌ مِنَ النِّفَاقِ، حَتَّى يَدَعَهَا إِذَا حَدَّثَ كَذَبَ، وَإِذَا وَعَدَ أَخْلَفَ، وَإِذَا عَاهَدَ غَدَرَ، وَإِذَا خَاصَمَ فَجَرَ ‏"‏‏.‏\hadithno{2459}\hadithtrans{Narrated `Abdullah bin `Amr:The Prophet (ﷺ) said, "Whoever has (the following) four characters will be a hypocrite, and whoever has one of the following four characteristics will have one characteristic of hypocrisy until he gives it up. These are: (1 ) Whenever he talks, he tells a lie; (2) whenever he makes a promise, he breaks it; (3) whenever he makes a covenant he proves treacherous; (4) and whenever he quarrels, he behaves impudently in an evil insulting manner." (See Hadith No. 33 Vol)}}
\hadithdefcmd{bukhari}{2460}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، حَدَّثَنِي عُرْوَةُ، أَنَّ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ جَاءَتْ هِنْدُ بِنْتُ عُتْبَةَ بْنِ رَبِيعَةَ، فَقَالَتْ يَا رَسُولَ اللَّهِ إِنَّ أَبَا سُفْيَانَ رَجُلٌ مِسِّيكٌ، فَهَلْ عَلَىَّ حَرَجٌ أَنْ أُطْعِمَ مِنَ الَّذِي لَهُ عِيَالَنَا فَقَالَ ‏ "‏ لاَ حَرَجَ عَلَيْكِ أَنْ تُطْعِمِيهِمْ بِالْمَعْرُوفِ ‏"‏‏.‏\hadithno{2460}\hadithtrans{Narrated Aisha:Hind bint `Utba (Abu Sufyan's wife) came and said, "O Allah's Messenger (ﷺ)! Abu Sufyan is a miser. Is there any harm if I spend something from his property for our children?" He said, there is no harm for you if you feed them from it justly and reasonably (with no extravagance)}}
\hadithdefcmd{bukhari}{2461}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، حَدَّثَنَا اللَّيْثُ، قَالَ حَدَّثَنِي يَزِيدُ، عَنْ أَبِي الْخَيْرِ، عَنْ عُقْبَةَ بْنِ عَامِرٍ، قَالَ قُلْنَا لِلنَّبِيِّ صلى الله عليه وسلم إِنَّكَ تَبْعَثُنَا فَنَنْزِلُ بِقَوْمٍ لاَ يَقْرُونَا فَمَا تَرَى فِيهِ فَقَالَ لَنَا ‏ "‏ إِنْ نَزَلْتُمْ بِقَوْمٍ، فَأُمِرَ لَكُمْ بِمَا يَنْبَغِي لِلضَّيْفِ فَاقْبَلُوا، فَإِنْ لَمْ يَفْعَلُوا فَخُذُوا مِنْهُمْ حَقَّ الضَّيْفِ ‏"‏‏.‏\hadithno{2461}\hadithtrans{Narrated `Uqba bin 'Amir:We said to the Prophet, "You send us out and it happens that we have to stay with people who do not entertain us. What do you think about it? He said to us, "If you stay with some people and they entertain you as they should for a guest, accept their hospitality, but if they don't, take the right of the guest from them}}
\hadithdefcmd{bukhari}{2462}{حَدَّثَنَا يَحْيَى بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنِي ابْنُ وَهْبٍ، قَالَ حَدَّثَنِي مَالِكٌ،‏.‏ وَأَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، أَنَّ ابْنَ عَبَّاسٍ، أَخْبَرَهُ عَنْ عُمَرَ ـ رضى الله عنهم ـ قَالَ حِينَ تَوَفَّى اللَّهُ نَبِيَّهُ صلى الله عليه وسلم إِنَّ الأَنْصَارَ اجْتَمَعُوا فِي سَقِيفَةِ بَنِي سَاعِدَةَ، فَقُلْتُ لأَبِي بَكْرٍ انْطَلِقْ بِنَا‏.‏ فَجِئْنَاهُمْ فِي سَقِيفَةِ بَنِي سَاعِدَةَ‏.‏\hadithno{2462}\hadithtrans{Narrated `Umar:When Allah took away the soul of His Prophet at his death, the Ansar assembled In the shed of Bani Sa`ida. I said to Abu Bakr, "Let us go." So, we came to them (i.e. to Ansar) at the shed of Bani Sa`ida. (See Hadith No. 19, Vol. 5 for details)}}
\hadithdefcmd{bukhari}{2463}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، رضى الله عنه أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَمْنَعُ جَارٌ جَارَهُ أَنْ يَغْرِزَ خَشَبَهُ فِي جِدَارِهِ ‏"‏‏.‏ ثُمَّ يَقُولُ أَبُو هُرَيْرَةَ مَا لِي أَرَاكُمْ عَنْهَا مُعْرِضِينَ وَاللَّهِ لأَرْمِيَنَّ بِهَا بَيْنَ أَكْتَافِكُمْ‏.‏\hadithno{2463}\hadithtrans{Narrated Al-Araj:Abu Huraira said, "Allah's Messenger (ﷺ) said, 'No one should prevent his neighbor from fixing a wooden peg in his wall." Abu Huraira said (to his companions), "Why do I find you averse to it? By Allah, I certainly will narrate it to you}}
\hadithdefcmd{bukhari}{2464}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الرَّحِيمِ أَبُو يَحْيَى، أَخْبَرَنَا عَفَّانُ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، حَدَّثَنَا ثَابِتٌ، عَنْ أَنَسٍ ـ رضى الله عنه ـ كُنْتُ سَاقِيَ الْقَوْمِ فِي مَنْزِلِ أَبِي طَلْحَةَ، وَكَانَ خَمْرُهُمْ يَوْمَئِذٍ الْفَضِيخَ، فَأَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم مُنَادِيًا يُنَادِي ‏"‏ أَلاَ إِنَّ الْخَمْرَ قَدْ حُرِّمَتْ ‏"‏‏.‏ قَالَ فَقَالَ لِي أَبُو طَلْحَةَ اخْرُجْ فَأَهْرِقْهَا، فَخَرَجْتُ فَهَرَقْتُهَا، فَجَرَتْ فِي سِكَكِ الْمَدِينَةِ فَقَالَ بَعْضُ الْقَوْمِ قَدْ قُتِلَ قَوْمٌ وَهْىَ فِي بُطُونِهِمْ‏.‏ فَأَنْزَلَ اللَّهُ ‏\{‏لَيْسَ عَلَى الَّذِينَ آمَنُوا وَعَمِلُوا الصَّالِحَاتِ جُنَاحٌ فِيمَا طَعِمُوا‏\}‏ الآيَةَ‏.‏\hadithno{2464}\hadithtrans{Narrated Anas:I was the butler of the people in the house of Abu Talha, and in those days drinks were prepared from dates. Allah's Messenger (ﷺ) ordered somebody to announce that alcoholic drinks had been prohibited. Abu Talha ordered me to go out and spill the wine. I went out and spilled it, and it flowed in the streets of Medina. Some people said, "Some people were killed and wine was still in their stomachs." On that the Divine revelation came:-- "On those who believe And do good deeds There is no blame For what they ate (in the past)}}
\hadithdefcmd{bukhari}{2465}{حَدَّثَنَا مُعَاذُ بْنُ فَضَالَةَ، حَدَّثَنَا أَبُو عُمَرَ، حَفْصُ بْنُ مَيْسَرَةَ عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ إِيَّاكُمْ وَالْجُلُوسَ عَلَى الطُّرُقَاتِ ‏"‏‏.‏ فَقَالُوا مَا لَنَا بُدٌّ، إِنَّمَا هِيَ مَجَالِسُنَا نَتَحَدَّثُ فِيهَا‏.‏ قَالَ ‏"‏ فَإِذَا أَبَيْتُمْ إِلاَّ الْمَجَالِسَ فَأَعْطُوا الطَّرِيقَ حَقَّهَا ‏"‏ قَالُوا وَمَا حَقُّ الطَّرِيقِ قَالَ ‏"‏ غَضُّ الْبَصَرِ، وَكَفُّ الأَذَى، وَرَدُّ السَّلاَمِ، وَأَمْرٌ بِالْمَعْرُوفِ، وَنَهْىٌ عَنِ الْمُنْكَرِ ‏"‏‏.‏\hadithno{2465}\hadithtrans{Narrated Abu Sa`id Al-Khudri:The Prophet (ﷺ) said, "Beware! Avoid sitting on the roads (ways)." The people said, "There is no way out of it as these are our sitting places where we have talks." The Prophet (ﷺ) said, "If you must sit there, then observe the rights of the way." They asked, "What are the rights of the way?" He said, "They are the lowering of your gazes (on seeing what is illegal to look at), refraining from harming people, returning greetings, advocating good and forbidding evil}}
\hadithdefcmd{bukhari}{2466}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ سُمَىٍّ، مَوْلَى أَبِي بَكْرٍ عَنْ أَبِي صَالِحٍ السَّمَّانِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ بَيْنَا رَجُلٌ بِطَرِيقٍ، اشْتَدَّ عَلَيْهِ الْعَطَشُ فَوَجَدَ بِئْرًا فَنَزَلَ فِيهَا فَشَرِبَ، ثُمَّ خَرَجَ، فَإِذَا كَلْبٌ يَلْهَثُ يَأْكُلُ الثَّرَى مِنَ الْعَطَشِ، فَقَالَ الرَّجُلُ لَقَدْ بَلَغَ هَذَا الْكَلْبَ مِنَ الْعَطَشِ مِثْلُ الَّذِي كَانَ بَلَغَ مِنِّي، فَنَزَلَ الْبِئْرَ، فَمَلأَ خُفَّهُ مَاءً، فَسَقَى الْكَلْبَ، فَشَكَرَ اللَّهُ لَهُ، فَغَفَرَ لَهُ ‏"‏‏.‏ قَالُوا يَا رَسُولَ اللَّهِ وَإِنَّ لَنَا فِي الْبَهَائِمِ لأَجْرًا فَقَالَ ‏"‏ فِي كُلِّ ذَاتِ كَبِدٍ رَطْبَةٍ أَجْرٌ ‏"‏‏.‏\hadithno{2466}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "A man felt very thirsty while he was on the way, there he came across a well. He went down the well, quenched his thirst and came out. Meanwhile he saw a dog panting and licking mud because of excessive thirst. He said to himself, "This dog is suffering from thirst as I did." So, he went down the well again and filled his shoe with water and watered it. Allah thanked him for that deed and forgave him. The people said, "O Allah's Messenger (ﷺ)! Is there a reward for us in serving the animals?" He replied: "Yes, there is a reward for serving any animate (living being)." (See Hadith No)}}
\hadithdefcmd{bukhari}{2467}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا ابْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ أُسَامَةَ بْنِ زَيْدٍ ـ رضى الله عنهما ـ قَالَ أَشْرَفَ النَّبِيُّ صلى الله عليه وسلم عَلَى أُطُمٍ مِنْ آطَامِ الْمَدِينَةِ ثُمَّ قَالَ ‏ "‏ هَلْ تَرَوْنَ مَا أَرَى إِنِّي أَرَى مَوَاقِعَ الْفِتَنِ خِلاَلَ بُيُوتِكُمْ كَمَوَاقِعِ الْقَطْرِ ‏"‏‏.‏\hadithno{2467}\hadithtrans{Narrated Usama bin Zaid:Once the Prophet (ﷺ) stood at the top of one of the castles (or higher buildings) of Medina and said, "Do you see what I see? No doubt I am seeing the spots of afflictions amongst your houses as numerous as the spots where raindrops fall (during a heavy rain). (See Hadith No)}}
\hadithdefcmd{bukhari}{2468}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ بْنِ أَبِي ثَوْرٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ لَمْ أَزَلْ حَرِيصًا عَلَى أَنْ أَسْأَلَ عُمَرَ ـ رضى الله عنه ـ عَنِ الْمَرْأَتَيْنِ مِنْ أَزْوَاجِ النَّبِيِّ صلى الله عليه وسلم اللَّتَيْنِ قَالَ اللَّهُ لَهُمَا ‏\{‏إِنْ تَتُوبَا إِلَى اللَّهِ فَقَدْ صَغَتْ قُلُوبُكُمَا‏\}‏ فَحَجَجْتُ مَعَهُ فَعَدَلَ وَعَدَلْتُ مَعَهُ بِالإِدَاوَةِ، فَتَبَرَّزَ حَتَّى جَاءَ، فَسَكَبْتُ عَلَى يَدَيْهِ مِنَ الإِدَاوَةِ، فَتَوَضَّأَ فَقُلْتُ يَا أَمِيرَ الْمُؤْمِنِينَ مَنِ الْمَرْأَتَانِ مِنْ أَزْوَاجِ النَّبِيِّ صلى الله عليه وسلم اللَّتَانِ قَالَ لَهُمَا ‏\{‏إِنْ تَتُوبَا إِلَى اللَّهِ‏\}‏ فَقَالَ وَاعَجَبِي لَكَ يَا ابْنَ عَبَّاسٍ عَائِشَةُ وَحَفْصَةُ، ثُمَّ اسْتَقْبَلَ عُمَرُ الْحَدِيثَ يَسُوقُهُ، فَقَالَ إِنِّي كُنْتُ وَجَارٌ لِي مِنَ الأَنْصَارِ فِي بَنِي أُمَيَّةَ بْنِ زَيْدٍ، وَهْىَ مِنْ عَوَالِي الْمَدِينَةِ، وَكُنَّا نَتَنَاوَبُ النُّزُولَ عَلَى النَّبِيِّ صلى الله عليه وسلم فَيَنْزِلُ يَوْمًا وَأَنْزِلُ يَوْمًا، فَإِذَا نَزَلْتُ جِئْتُهُ مِنْ خَبَرِ ذَلِكَ الْيَوْمِ مِنَ الأَمْرِ وَغَيْرِهِ، وَإِذَا نَزَلَ فَعَلَ مِثْلَهُ، وَكُنَّا مَعْشَرَ قُرَيْشٍ نَغْلِبُ النِّسَاءَ، فَلَمَّا قَدِمْنَا عَلَى الأَنْصَارِ إِذَا هُمْ قَوْمٌ تَغْلِبُهُمْ نِسَاؤُهُمْ، فَطَفِقَ نِسَاؤُنَا يَأْخُذْنَ مِنْ أَدَبِ نِسَاءِ الأَنْصَارِ، فَصِحْتُ عَلَى امْرَأَتِي، فَرَاجَعَتْنِي، فَأَنْكَرْتُ أَنْ تُرَاجِعَنِي، فَقَالَتْ وَلِمَ تُنْكِرُ أَنْ أُرَاجِعَكَ فَوَاللَّهِ إِنَّ أَزْوَاجَ النَّبِيِّ صلى الله عليه وسلم لَيُرَاجِعْنَهُ، وَإِنَّ إِحْدَاهُنَّ لَتَهْجُرُهُ الْيَوْمَ حَتَّى اللَّيْلِ‏.‏ فَأَفْزَعَنِي، فَقُلْتُ خَابَتْ مَنْ فَعَلَ مِنْهُنَّ بِعَظِيمٍ‏.‏ ثُمَّ جَمَعْتُ عَلَىَّ ثِيَابِي، فَدَخَلْتُ عَلَى حَفْصَةَ فَقُلْتُ أَىْ حَفْصَةُ، أَتُغَاضِبُ إِحْدَاكُنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم الْيَوْمَ حَتَّى اللَّيْلِ فَقَالَتْ نَعَمْ‏.‏ فَقُلْتُ خَابَتْ وَخَسِرَتْ، أَفَتَأْمَنُ أَنْ يَغْضَبَ اللَّهُ لِغَضَبِ رَسُولِهِ صلى الله عليه وسلم فَتَهْلِكِينَ لاَ تَسْتَكْثِرِي عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَلاَ تُرَاجِعِيهِ فِي شَىْءٍ وَلاَ تَهْجُرِيهِ، وَاسْأَلِينِي مَا بَدَا لَكِ، وَلاَ يَغُرَّنَّكِ أَنْ كَانَتْ جَارَتُكِ هِيَ أَوْضَأَ مِنْكِ وَأَحَبَّ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم ـ يُرِيدُ عَائِشَةَ ـ وَكُنَّا تَحَدَّثْنَا أَنَّ غَسَّانَ تُنْعِلُ النِّعَالَ لِغَزْوِنَا، فَنَزَلَ صَاحِبِي يَوْمَ نَوْبَتِهِ فَرَجَعَ عِشَاءً، فَضَرَبَ بَابِي ضَرْبًا شَدِيدًا، وَقَالَ أَنَائِمٌ هُوَ فَفَزِعْتُ فَخَرَجْتُ إِلَيْهِ‏.‏ وَقَالَ حَدَثَ أَمْرٌ عَظِيمٌ‏.‏ قُلْتُ مَا هُوَ أَجَاءَتْ غَسَّانُ قَالَ لاَ، بَلْ أَعْظَمُ مِنْهُ وَأَطْوَلُ، طَلَّقَ رَسُولُ اللَّهِ صلى الله عليه وسلم نِسَاءَهُ‏.‏ قَالَ قَدْ خَابَتْ حَفْصَةُ وَخَسِرَتْ، كُنْتُ أَظُنُّ أَنَّ هَذَا يُوشِكُ أَنْ يَكُونَ، فَجَمَعْتُ عَلَىَّ ثِيَابِي، فَصَلَّيْتُ صَلاَةَ الْفَجْرِ مَعَ النَّبِيِّ صلى الله عليه وسلم فَدَخَلَ مَشْرُبَةً لَهُ فَاعْتَزَلَ فِيهَا، فَدَخَلْتُ عَلَى حَفْصَةَ، فَإِذَا هِيَ تَبْكِي‏.‏ قُلْتُ مَا يُبْكِيكِ أَوَلَمْ أَكُنْ حَذَّرْتُكِ أَطَلَّقَكُنَّ رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَتْ لاَ أَدْرِي هُوَ ذَا فِي الْمَشْرُبَةِ‏.‏ فَخَرَجْتُ، فَجِئْتُ الْمِنْبَرَ، فَإِذَا حَوْلَهُ رَهْطٌ يَبْكِي بَعْضُهُمْ، فَجَلَسْتُ مَعَهُمْ قَلِيلاً ثُمَّ غَلَبَنِي مَا أَجِدُ، فَجِئْتُ الْمَشْرُبَةَ الَّتِي هُوَ فِيهَا فَقُلْتُ لِغُلاَمٍ لَهُ أَسْوَدَ اسْتَأْذِنْ لِعُمَرَ‏.‏ فَدَخَلَ، فَكَلَّمَ النَّبِيَّ صلى الله عليه وسلم ثُمَّ خَرَجَ، فَقَالَ ذَكَرْتُكَ لَهُ، فَصَمَتَ، فَانْصَرَفْتُ حَتَّى جَلَسْتُ مَعَ الرَّهْطِ الَّذِينَ عِنْدَ الْمِنْبَرِ، ثُمَّ غَلَبَنِي مَا أَجِدُ فَجِئْتُ، فَذَكَرَ مِثْلَهُ، فَجَلَسْتُ مَعَ الرَّهْطِ الَّذِينَ عِنْدَ الْمِنْبَرِ، ثُمَّ غَلَبَنِي مَا أَجِدُ فَجِئْتُ الْغُلاَمَ‏.‏ فَقُلْتُ اسْتَأْذِنْ لِعُمَرَ‏.‏ فَذَكَرَ مِثْلَهُ، فَلَمَّا وَلَّيْتُ مُنْصَرِفًا، فَإِذَا الْغُلاَمُ يَدْعُونِي قَالَ أَذِنَ لَكَ رَسُولُ اللَّهِ صلى الله عليه وسلم‏.‏ فَدَخَلْتُ عَلَيْهِ، فَإِذَا هُوَ مُضْطَجِعٌ عَلَى رِمَالِ حَصِيرٍ لَيْسَ بَيْنَهُ وَبَيْنَهُ فِرَاشٌ، قَدْ أَثَّرَ الرِّمَالُ بِجَنْبِهِ، مُتَّكِئٌ عَلَى وِسَادَةٍ مِنْ أَدَمٍ حَشْوُهَا لِيفٌ، فَسَلَّمْتُ عَلَيْهِ، ثُمَّ قُلْتُ وَأَنَا قَائِمٌ طَلَّقْتَ نِسَاءَكَ فَرَفَعَ بَصَرَهُ إِلَىَّ، فَقَالَ ‏"‏ لاَ ‏"‏‏.‏ ثُمَّ قُلْتُ ـ وَأَنَا قَائِمٌ أَسْتَأْنِسُ يَا رَسُولَ اللَّهِ، لَوْ رَأَيْتَنِي، وَكُنَّا مَعْشَرَ قُرَيْشٍ نَغْلِبُ النِّسَاءَ، فَلَمَّا قَدِمْنَا عَلَى قَوْمٍ تَغْلِبُهُمْ نِسَاؤُهُمْ، فَذَكَرَهُ، فَتَبَسَّمَ النَّبِيُّ صلى الله عليه وسلم، ثُمَّ قُلْتُ لَوْ رَأَيْتَنِي، وَدَخَلْتُ عَلَى حَفْصَةَ، فَقُلْتُ لاَ يَغُرَّنَّكِ أَنْ كَانَتْ جَارَتُكِ هِيَ أَوْضَأَ مِنْكِ وَأَحَبَّ إِلَى النَّبِيِّ صلى الله عليه وسلم ـ يُرِيدُ عَائِشَةَ ـ فَتَبَسَّمَ أُخْرَى، فَجَلَسْتُ حِينَ رَأَيْتُهُ تَبَسَّمَ، ثُمَّ رَفَعْتُ بَصَرِي فِي بَيْتِهِ، فَوَاللَّهِ مَا رَأَيْتُ فِيهِ شَيْئًا يَرُدُّ الْبَصَرَ غَيْرَ أَهَبَةٍ ثَلاَثَةٍ‏.‏ فَقُلْتُ ادْعُ اللَّهَ فَلْيُوَسِّعْ عَلَى أُمَّتِكَ، فَإِنَّ فَارِسَ وَالرُّومَ وُسِّعَ عَلَيْهِمْ وَأُعْطُوا الدُّنْيَا، وَهُمْ لاَ يَعْبُدُونَ اللَّهَ، وَكَانَ مُتَّكِئًا‏.‏ فَقَالَ ‏"‏ أَوَفِي شَكٍّ أَنْتَ يَا ابْنَ الْخَطَّابِ أُولَئِكَ قَوْمٌ عُجِّلَتْ لَهُمْ طَيِّبَاتُهُمْ فِي الْحَيَاةِ الدُّنْيَا ‏"‏‏.‏ فَقُلْتُ يَا رَسُولَ اللَّهِ اسْتَغْفِرْ لِي‏.‏ فَاعْتَزَلَ النَّبِيُّ صلى الله عليه وسلم مِنْ أَجْلِ ذَلِكَ الْحَدِيثِ حِينَ أَفْشَتْهُ حَفْصَةُ إِلَى عَائِشَةَ، وَكَانَ قَدْ قَالَ ‏"‏ مَا أَنَا بِدَاخِلٍ عَلَيْهِنَّ شَهْرًا ‏"‏‏.‏ مِنْ شِدَّةِ مَوْجَدَتِهِ عَلَيْهِنَّ حِينَ عَاتَبَهُ اللَّهُ‏.‏ فَلَمَّا مَضَتْ تِسْعٌ وَعِشْرُونَ دَخَلَ عَلَى عَائِشَةَ فَبَدَأَ بِهَا، فَقَالَتْ لَهُ عَائِشَةُ إِنَّكَ أَقْسَمْتَ أَنْ لاَ تَدْخُلَ عَلَيْنَا شَهْرًا، وَإِنَّا أَصْبَحْنَا لِتِسْعٍ وَعِشْرِينَ لَيْلَةً، أَعُدُّهَا عَدًّا‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ الشَّهْرُ تِسْعٌ وَعِشْرُونَ ‏"‏‏.‏ وَكَانَ ذَلِكَ الشَّهْرُ تِسْعٌ وَعِشْرُونَ‏.‏ قَالَتْ عَائِشَةُ فَأُنْزِلَتْ آيَةُ التَّخْيِيرِ فَبَدَأَ بِي أَوَّلَ امْرَأَةٍ، فَقَالَ ‏"‏ إِنِّي ذَاكِرٌ لَكِ أَمْرًا، وَلاَ عَلَيْكِ أَنْ لاَ تَعْجَلِي حَتَّى تَسْتَأْمِرِي أَبَوَيْكِ ‏"‏‏.‏ قَالَتْ قَدْ أَعْلَمُ أَنَّ أَبَوَىَّ لَمْ يَكُونَا يَأْمُرَانِي بِفِرَاقِكَ‏.‏ ثُمَّ قَالَ ‏"‏ إِنَّ اللَّهَ قَالَ ‏\{‏يَا أَيُّهَا النَّبِيُّ قُلْ لأَزْوَاجِكَ‏\}‏ إِلَى قَوْلِهِ ‏\{‏ عَظِيمًا‏\}‏ ‏"‏‏.‏ قُلْتُ أَفِي هَذَا أَسْتَأْمِرُ أَبَوَىَّ فَإِنِّي أُرِيدُ اللَّهَ وَرَسُولَهُ وَالدَّارَ الآخِرَةَ‏.‏ ثُمَّ خَيَّرَ نِسَاءَهُ، فَقُلْنَ مِثْلَ مَا قَالَتْ عَائِشَةُ‏.‏\hadithno{2468}\hadithtrans{Narrated `Abdullah bin `Abbas:I had been eager to ask `Umar about the two ladies from among the wives of the Prophet (ﷺ) regarding whom Allah said (in the Qur'an saying): If you two (wives of the Prophet (ﷺ) namely Aisha and Hafsa) turn in repentance to Allah your hearts are indeed so inclined (to oppose what the Prophet (ﷺ) likes) (66.4), till performed the Hajj along with `Umar (and on our way back from Hajj) he went aside (to answer the call of nature) and I also went aside along with him carrying a tumbler of water. When he had answered the call of nature and returned. I poured water on his hands from the tumbler and he performed ablution. I said, "O Chief of the believers! ' Who were the two ladies from among the wives of the Prophet (ﷺ) to whom Allah said: 'If you two return in repentance (66.4)? He said, "I am astonished at your question, O Ibn `Abbas. They were Aisha and Hafsa." Then `Umar went on relating the narration and said. "I and an Ansari neighbor of mine from Bani Umaiya bin Zaid who used to live in `Awali Al-Medina, used to visit the Prophet (ﷺ) in turns. He used to go one day, and I another day. When I went I would bring him the news of what had happened that day regarding the instructions and orders and when he went, he used to do the same for me. We, the people of Quraish, used to have authority over women, but when we came to live with the Ansar, we noticed that the Ansari women had the upper hand over their men, so our women started acquiring the habits of the Ansari women. Once I shouted at my wife and she paid me back in my coin and I disliked that she should answer me back. She said, 'Why do you take it ill that I retort upon you? By Allah, the wives of the Prophet (ﷺ) retort upon him, and some of them may not speak with him for the whole day till night.' What she said scared me and I said to her, 'Whoever amongst them does so, will be a great loser.' Then I dressed myself and went to Hafsa and asked her, 'Does any of you keep Allah's Messenger (ﷺ) angry all the day long till night?' She replied in the affirmative. I said, 'She is a ruined losing person (and will never have success)! Doesn't she fear that Allah may get angry for the anger of Allah's Messenger (ﷺ) and thus she will be ruined? Don't ask Allah's Messenger (ﷺ) too many things, and don't retort upon him in any case, and don't desert him. Demand from me whatever you like, and don't be tempted to imitate your neighbor (i.e. `Aisha) in her behavior towards the Prophet), for she (i.e. Aisha) is more beautiful than you, and more beloved to Allah's Messenger (ﷺ). In those days it was rumored that Ghassan, (a tribe living in Sham) was getting prepared their horses to invade us. My companion went (to the Prophet (ﷺ) on the day of his turn, went and returned to us at night and knocked at my door violently, asking whether I was sleeping. I was scared (by the hard knocking) and came out to him. He said that a great thing had happened. I asked him: What is it? Have Ghassan come? He replied that it was worse and more serious than that, and added that Allah's Apostle had divorced all his wives. I said, Hafsa is a ruined loser! I expected that would happen some day.' So I dressed myself and offered the Fajr prayer with the Prophet. Then the Prophet (ﷺ) entered an upper room and stayed there alone. I went to Hafsa and found her weeping. I asked her, 'Why are you weeping? Didn't I warn you? Has Allah's Messenger (ﷺ) divorced you all?' She replied, 'I don't know. He is there in the upper room.' I then went out and came to the pulpit and found a group of people around it and some of them were weeping. Then I sat with them for some time, but could not endure the situation. So I went to the upper room where the Prophet (ﷺ) was and requested to a black slave of his: "Will you get the permission of (Allah's Apostle) for `Umar (to enter)? The slave went in, talked to the Prophet (ﷺ) about it and came out saying, 'I mentioned you to him but he did not reply.' So, I went and sat with the people who were sitting by the pulpit, but I could not bear the situation, so I went to the slave again and said: "Will you get he permission for `Umar? He went in and brought the same reply as before. When I was leaving, behold, the slave called me saying, "Allah's Messenger (ﷺ) has granted you permission." So, I entered upon the Prophet and saw him lying on a mat without bedding on it, and the mat had left its mark on the body of the Prophet, and he was leaning on a leather pillow stuffed with palm fibres. I greeted him and while still standing, I said: "Have you divorced your wives?' He raised his eyes to me and replied in the negative. And then while still standing, I said chatting: "Will you heed what I say, 'O Allah's Messenger (ﷺ)! We, the people of Quraish used to have the upper hand over our women (wives), and when we came to the people whose women had the upper hand over them..." `Umar told the whole story (about his wife). "On that the Prophet (ﷺ) smiled." `Umar further said, "I then said, 'I went to Hafsa and said to her: Do not be tempted to imitate your companion (`Aisha) for she is more beautiful than you and more beloved to the Prophet.' The Prophet (ﷺ) smiled again. When I saw him smiling, I sat down and cast a glance at the room, and by Allah, I couldn't see anything of importance but three hides. I said (to Allah's Messenger (ﷺ)) "Invoke Allah to make your followers prosperous for the Persians and the Byzantines have been made prosperous and given worldly luxuries, though they do not worship Allah?' The Prophet (ﷺ) was leaning then (and on hearing my speech he sat straight) and said, 'O Ibn Al-Khattab! Do you have any doubt (that the Hereafter is better than this world)? These people have been given rewards of their good deeds in this world only.' I asked the Prophet (ﷺ) . 'Please ask Allah's forgiveness for me. The Prophet (ﷺ) did not go to his wives because of the secret which Hafsa had disclosed to `Aisha, and he said that he would not go to his wives for one month as he was angry with them when Allah admonished him (for his oath that he would not approach Maria). When twenty-nine days had passed, the Prophet (ﷺ) went to Aisha first of all. She said to him, 'You took an oath that you would not come to us for one month, and today only twenty-nine days have passed, as I have been counting them day by day.' The Prophet (ﷺ) said, 'The month is also of twenty-nine days.' That month consisted of twenty-nine days. `Aisha said, 'When the Divine revelation of Choice was revealed, the Prophet (ﷺ) started with me, saying to me, 'I am telling you something, but you need not hurry to give the reply till you can consult your parents." `Aisha knew that her parents would not advise her to part with the Prophet (ﷺ) . The Prophet (ﷺ) said that Allah had said: 'O Prophet! Say To your wives; If you desire The life of this world And its glitter, ... then come! I will make a provision for you and set you free In a handsome manner. But if you seek Allah And His Apostle, and The Home of the Hereafter, then Verily, Allah has prepared For the good-doers amongst you A great reward.' (33.28) `Aisha said, 'Am I to consult my parents about this? I indeed prefer Allah, His Apostle, and the Home of the Hereafter.' After that the Prophet (ﷺ) gave the choice to his other wives and they also gave the same reply as `Aisha did}}
\hadithdefcmd{bukhari}{2469}{حَدَّثَنَا ابْنُ سَلاَمٍ، حَدَّثَنَا الْفَزَارِيُّ، عَنْ حُمَيْدٍ الطَّوِيلِ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ آلَى رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ نِسَائِهِ شَهْرًا، وَكَانَتِ انْفَكَّتْ قَدَمُهُ فَجَلَسَ فِي عِلِّيَّةٍ لَهُ، فَجَاءَ عُمَرُ، فَقَالَ أَطَلَّقْتَ نِسَاءَكَ قَالَ ‏ "‏ لاَ، وَلَكِنِّي آلَيْتُ مِنْهُنَّ شَهْرًا ‏"‏‏.‏ فَمَكُثَ تِسْعًا وَعِشْرِينَ، ثُمَّ نَزَلَ، فَدَخَلَ عَلَى نِسَائِهِ‏.‏\hadithno{2469}\hadithtrans{Narrated Anas:Allah's Messenger (ﷺ) took an oath that he would not go to his wives for one month as his foot had been sprained. He stayed in an upper room when `Umar went to him and said, "Have you divorced your wives?" He said, "No, but I have taken an oath that I would not go to them for one month." The Prophet stayed there for twenty-nine days, and then came down and went to his wives}}
\hadithdefcmd{bukhari}{2470}{حَدَّثَنَا مُسْلِمٌ، حَدَّثَنَا أَبُو عَقِيلٍ، حَدَّثَنَا أَبُو الْمُتَوَكِّلِ النَّاجِيُّ، قَالَ أَتَيْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ قَالَ دَخَلَ النَّبِيُّ صلى الله عليه وسلم الْمَسْجِدَ، فَدَخَلْتُ إِلَيْهِ، وَعَقَلْتُ الْجَمَلَ فِي نَاحِيَةِ الْبَلاَطِ فَقُلْتُ هَذَا جَمَلُكَ‏.‏ فَخَرَجَ فَجَعَلَ يُطِيفُ بِالْجَمَلِ قَالَ ‏ "‏ الثَّمَنُ وَالْجَمَلُ لَكَ ‏"‏‏.‏\hadithno{2470}\hadithtrans{Narrated Jabir:The Prophet (ﷺ) entered the Mosque, and I too went there after tying the camel at the pavement of the Mosque. I said (to the Prophet (ﷺ) ), "This is your camel." He came out and started examining the camel and said, "Both the camel and its price are for you}}
\hadithdefcmd{bukhari}{2471}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، عَنْ شُعْبَةَ، عَنْ مَنْصُورٍ، عَنْ أَبِي وَائِلٍ، عَنْ حُذَيْفَةَ ـ رضى الله عنه ـ قَالَ لَقَدْ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم، أَوْ قَالَ لَقَدْ أَتَى النَّبِيُّ صلى الله عليه وسلم سُبَاطَةَ قَوْمٍ فَبَالَ قَائِمًا‏.‏\hadithno{2471}\hadithtrans{Narrated Hudhaifa:I saw Allah's Messenger (ﷺ) coming (or the Prophet (ﷺ) came) to the dumps of some people and urinated there while standing}}
\hadithdefcmd{bukhari}{2472}{حَدَّثَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا مَالِكٌ، عَنْ سُمَىٍّ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ بَيْنَمَا رَجُلٌ يَمْشِي بِطَرِيقٍ، وَجَدَ غُصْنَ شَوْكٍ فَأَخَذَهُ، فَشَكَرَ اللَّهُ لَهُ، فَغَفَرَ لَهُ ‏"‏‏.‏\hadithno{2472}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "While a man was on the way, he found a thorny branch of a tree there on the way and removed it. Allah thanked him for that deed and forgave him}}
\hadithdefcmd{bukhari}{2473}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا جَرِيرُ بْنُ حَازِمٍ، عَنِ الزُّبَيْرِ بْنِ خِرِّيتٍ، عَنْ عِكْرِمَةَ، سَمِعْتُ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَضَى النَّبِيُّ صلى الله عليه وسلم إِذَا تَشَاجَرُوا فِي الطَّرِيقِ بِسَبْعَةِ أَذْرُعٍ‏.‏\hadithno{2473}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) judged that seven cubits should be left as a public way when there was a dispute about the land}}
\hadithdefcmd{bukhari}{2474}{حَدَّثَنَا آدَمُ بْنُ أَبِي إِيَاسٍ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا عَدِيُّ بْنُ ثَابِتٍ، سَمِعْتُ عَبْدَ اللَّهِ بْنَ يَزِيدَ الأَنْصَارِيّ َ ـ وَهُوَ جَدُّهُ أَبُو أُمِّهِ ـ قَالَ نَهَى النَّبِيُّ صلى الله عليه وسلم عَنِ النُّهْبَى وَالْمُثْلَةِ‏.‏\hadithno{2474}\hadithtrans{Narrated `Abdullah bin Yazid Al-Ansari:The Prophet (ﷺ) forbade robbery (taking away what belongs to others without their permission), and also forbade mutilation (or maiming) of bodies}}
\hadithdefcmd{bukhari}{2475}{حَدَّثَنَا سَعِيدُ بْنُ عُفَيْرٍ، قَالَ حَدَّثَنِي اللَّيْثُ، حَدَّثَنَا عُقَيْلٌ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي بَكْرِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لاَ يَزْنِي الزَّانِي حِينَ يَزْنِي وَهْوَ مُؤْمِنٌ، وَلاَ يَشْرَبُ الْخَمْرَ حِينَ يَشْرَبُ وَهْوَ مُؤْمِنٌ، وَلاَ يَسْرِقُ حِينَ يَسْرِقُ وَهْوَ مُؤْمِنٌ، وَلاَ يَنْتَهِبُ نُهْبَةً يَرْفَعُ النَّاسُ إِلَيْهِ فِيهَا أَبْصَارَهُمْ حِينَ يَنْتَهِبُهَا وَهْوَ مُؤْمِنٌ ‏"‏‏.‏ وَعَنْ سَعِيدٍ وَأَبِي سَلَمَةَ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم مِثْلَهُ إِلاَّ النُّهْبَةَ‏.‏\hadithno{2475}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "When an adulterer commits illegal sexual intercourse, then he is not a believer at the time, he is doing it, and when a drinker of an alcoholic liquor drinks it, then he is not a believer at the time of drinking it, and when a thief steals, then he is not a believer at the time of stealing, and when a robber robs, and the people look at him, then he is not a believer at the time of doing robbery}}
\hadithdefcmd{bukhari}{2476}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا الزُّهْرِيُّ، قَالَ أَخْبَرَنِي سَعِيدُ بْنُ الْمُسَيَّبِ، سَمِعَ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَقُومُ السَّاعَةُ حَتَّى يَنْزِلَ فِيكُمُ ابْنُ مَرْيَمَ حَكَمًا مُقْسِطًا، فَيَكْسِرَ الصَّلِيبَ، وَيَقْتُلَ الْخِنْزِيرَ، وَيَضَعَ الْجِزْيَةَ، وَيَفِيضَ الْمَالُ حَتَّى لاَ يَقْبَلَهُ أَحَدٌ ‏"‏‏.‏\hadithno{2476}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "The Hour will not be established until the son of Mary (i.e. Jesus) descends amongst you as a just ruler, he will break the cross, kill the pigs, and abolish the Jizya tax. Money will be in abundance so that nobody will accept it (as charitable gifts)}}
\hadithdefcmd{bukhari}{2477}{حَدَّثَنَا أَبُو عَاصِمٍ الضَّحَّاكُ بْنُ مَخْلَدٍ، عَنْ يَزِيدَ بْنِ أَبِي عُبَيْدٍ، عَنْ سَلَمَةَ بْنِ الأَكْوَعِ ـ رضى الله عنه ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم رَأَى نِيرَانًا تُوقَدُ يَوْمَ خَيْبَرَ‏.‏ قَالَ ‏"‏ عَلَى مَا تُوقَدُ هَذِهِ النِّيرَانُ ‏"‏‏.‏ قَالُوا عَلَى الْحُمُرِ الإِنْسِيَّةِ‏.‏ قَالَ ‏"‏ اكْسِرُوهَا، وَأَهْرِقُوهَا ‏"‏‏.‏ قَالُوا أَلاَ نُهْرِيقُهَا وَنَغْسِلُهَا قَالَ ‏"‏ اغْسِلُوا ‏"‏‏.‏ قَالَ أَبُو عَبْد اللَّهِ كَانَ ابْنُ أَبِي أُوَيْسٍ يَقُولُ الْحُمُرِ الْأَنْسِيَّةِ بِنَصْبِ الْأَلِفِ وَالنُّونِ\hadithno{2477}\hadithtrans{Narrated Salama bin Al-Akwa`:On the day of Khaibar the Prophet (ﷺ) saw fires being lighted. He asked, "Why are these fires being lighted?" The people replied that they were cooking the meat of donkeys. He said, "Break the pots and throw away their contents." The people said, "Shall we throw away their contents and wash the pots (rather than break them)?" He said, "Wash them}}
\hadithdefcmd{bukhari}{2478}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا ابْنُ أَبِي نَجِيحٍ، عَنْ مُجَاهِدٍ، عَنْ أَبِي مَعْمَرٍ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ ـ رضى الله عنه ـ قَالَ دَخَلَ النَّبِيُّ صلى الله عليه وسلم مَكَّةَ، وَحَوْلَ الْكَعْبَةِ ثَلاَثُمِائَةٍ وَسِتُّونَ نُصُبًا فَجَعَلَ يَطْعَنُهَا بِعُودٍ فِي يَدِهِ وَجَعَلَ يَقُولُ ‏\{‏جَاءَ الْحَقُّ وَزَهَقَ الْبَاطِلُ‏\}‏ الآيَةَ‏.‏\hadithno{2478}\hadithtrans{Narrated `Abdullah bin Mas`ud:The Prophet (ﷺ) entered Mecca and (at that time) there were three hundred-and-sixty idols around the Ka`ba. He started stabbing the idols with a stick he had in his hand and reciting: "Truth (Islam) has come and Falsehood (disbelief) has vanished}}
\hadithdefcmd{bukhari}{2479}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْمُنْذِرِ، حَدَّثَنَا أَنَسُ بْنُ عِيَاضٍ، عَنْ عُبَيْدِ اللَّهِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ الْقَاسِمِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّهَا كَانَتِ اتَّخَذَتْ عَلَى سَهْوَةٍ لَهَا سِتْرًا فِيهِ تَمَاثِيلُ، فَهَتَكَهُ النَّبِيُّ صلى الله عليه وسلم، فَاتَّخَذَتْ مِنْهُ نُمْرُقَتَيْنِ، فَكَانَتَا فِي الْبَيْتِ يَجْلِسُ عَلَيْهِمَا‏.‏\hadithno{2479}\hadithtrans{Narrated Al-Qasim:Aisha said that she hung a curtain decorated with pictures (of animals) on a cupboard. The Prophet (ﷺ) tore that curtain and she turned it into two cushions which remained in the house for the Prophet (ﷺ) to sit on}}
\hadithdefcmd{bukhari}{2480}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يَزِيدَ، حَدَّثَنَا سَعِيدٌ ـ هُوَ ابْنُ أَبِي أَيُّوبَ ـ قَالَ حَدَّثَنِي أَبُو الأَسْوَدِ، عَنْ عِكْرِمَةَ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو ـ رضى الله عنهما ـ قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ قُتِلَ دُونَ مَالِهِ فَهُوَ شَهِيدٌ ‏"‏‏.‏\hadithno{2480}\hadithtrans{Narrated `Abdullah bin `Amr bin Al-`As:I heard the Prophet (ﷺ) saying, "Whoever is killed while protecting his property then he is a martyr}}
\hadithdefcmd{bukhari}{2481}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ حُمَيْدٍ، عَنْ أَنَسٍ ـ رضى الله عنه ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ عِنْدَ بَعْضِ نِسَائِهِ، فَأَرْسَلَتْ إِحْدَى أُمَّهَاتِ الْمُؤْمِنِينَ مَعَ خَادِمٍ بِقَصْعَةٍ فِيهَا طَعَامٌ فَضَرَبَتْ بِيَدِهَا، فَكَسَرَتِ الْقَصْعَةَ، فَضَمَّهَا، وَجَعَلَ فِيهَا الطَّعَامَ وَقَالَ ‏ "‏ كُلُوا ‏"‏‏.‏ وَحَبَسَ الرَّسُولَ وَالْقَصْعَةَ حَتَّى فَرَغُوا، فَدَفَعَ الْقَصْعَةَ الصَّحِيحَةَ وَحَبَسَ الْمَكْسُورَةَ‏.‏ وَقَالَ ابْنُ أَبِي مَرْيَمَ أَخْبَرَنَا يَحْيَى بْنُ أَيُّوبَ، حَدَّثَنَا حُمَيْدٌ، حَدَّثَنَا أَنَسٌ، عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{2481}\hadithtrans{Narrated Anas:While the Prophet (ﷺ) was with one of his wives, one of the mothers of the believers (i.e. one of his wives) sent a wooden bowl containing food with a servant. The wife (in whose house he was sitting) stroke the bowl with her hand and broke it. The Prophet (ﷺ) collected the shattered pieces and put the food back in it and said, "Eat." He kept the servant and the bowl till he had eaten the food. Then the Prophet gave another unbroken. bowl to the servant and kept the broken one}}
\hadithdefcmd{bukhari}{2482}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا جَرِيرُ بْنُ حَازِمٍ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ كَانَ رَجُلٌ فِي بَنِي إِسْرَائِيلَ، يُقَالُ لَهُ جُرَيْجٌ، يُصَلِّي، فَجَاءَتْهُ أُمُّهُ فَدَعَتْهُ، فَأَبَى أَنْ يُجِيبَهَا، فَقَالَ أُجِيبُهَا أَوْ أُصَلِّي ثُمَّ أَتَتْهُ، فَقَالَتِ اللَّهُمَّ لاَ تُمِتْهُ حَتَّى تُرِيَهُ الْمُومِسَاتِ‏.‏ وَكَانَ جُرَيْجٌ فِي صَوْمَعَتِهِ، فَقَالَتِ امْرَأَةٌ لأَفْتِنَنَّ جُرَيْجًا‏.‏ فَتَعَرَّضَتْ لَهُ فَكَلَّمَتْهُ فَأَبَى، فَأَتَتْ رَاعِيًا، فَأَمْكَنَتْهُ مِنْ نَفْسِهَا فَوَلَدَتْ غُلاَمًا، فَقَالَتْ هُوَ مِنْ جُرَيْجٍ‏.‏ فَأَتَوْهُ، وَكَسَرُوا صَوْمَعَتَهُ فَأَنْزَلُوهُ وَسَبُّوهُ، فَتَوَضَّأَ وَصَلَّى ثُمَّ أَتَى الْغُلاَمَ، فَقَالَ مَنْ أَبُوكَ يَا غُلاَمُ قَالَ الرَّاعِي‏.‏ قَالُوا نَبْنِي صَوْمَعَتَكَ مِنْ ذَهَبٍ‏.‏ قَالَ لاَ إِلاَّ مِنْ طِينٍ ‏"‏‏.‏\hadithno{2482}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "There was an Israeli man called Juraij, while he was praying, his mother came and called him, but he did not respond to her call. He said (to himself) whether he should continue the prayer or reply to his mother. She came to him the second time and called him and said, "O Allah! Do not let him die until he sees the faces of prostitutes." Juraij used to live in a hermitage. A woman said that she would entice Juraij, so she went to him and presented herself (for an evil act) but he refused. She then went to a shepherd and allowed him to commit an illegal sexual intercourse with her and later she gave birth to a boy. She alleged that the baby was from Juraij. The people went to Juraij and broke down his hermitage, pulled him out of it and abused him. He performed ablution and offered the prayer, then he went to the male (baby) and asked him; "O boy! Who is your father?" The baby replied that his father was the shepherd. The people said that they would build for him a hermitage of gold but Juraij asked them to make it of mud only}}
